// Copyright (c) Mito
import React, { useState, useRef, useEffect } from 'react';
import { ModalEnum } from '../Mito';
import BlueMitoFolk from '../icons/mitofolks/BlueMitoFolk';
import PinkMitoFolk from '../icons/mitofolks/PinkMitoFolk';
import YellowMitoFolk from '../icons/mitofolks/YellowMitoFolk';
import '../../../css/signup-modal.css';
/*
    This file contains all the screens used in the signup modal. As these
    are only used in this one file, we keep them together for cleanlyness.
*/
/* Step one requires an email input */
const StepOne = (props) => {
    // Make sure the input is focused on, as we want the experience of sign up
    // to be as fluid as possible, and the autofocus does not work for this 
    // input element, for some reason
    const emailInputRef = useRef(null);
    useEffect(() => {
        var _a;
        (_a = emailInputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    });
    const onSubmit = async (e) => {
        e.preventDefault();
        await props.mitoAPI.sendSignUp(props.email);
        props.next();
    };
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("div", null,
            React.createElement("h1", { className: 'mt-0' }, "Sign Up for Mito"),
            React.createElement("p", { className: 'signup-modal-text' }, "We\u2019ll send you periodic product updates and welcome any feedback. And no spam. Duh.")),
        React.createElement("form", { className: 'signup-modal-email-form', onSubmit: onSubmit },
            React.createElement("h3", { className: 'mb-20px' }, "Your Email"),
            React.createElement("input", { ref: emailInputRef, className: 'input', type: 'email', value: props.email, onChange: (event) => { props.setEmail(event.target.value); }, placeholder: 'example@gmail.com', required: true, autoFocus: true }),
            React.createElement("button", { className: 'signup-modal-button-signup', type: 'submit' }, " Sign Up"))));
};
/* Step one requires the user to read the privacy policy */
const StepTwo = (props) => {
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("div", null,
            React.createElement("h1", { className: 'mt-0' }, "Mito is Built for Privacy"),
            React.createElement("p", { className: 'signup-modal-text' },
                "We make sure none of your private data leaves your computer. Read our CCPA compliant privacy policy ",
                React.createElement("a", { href: 'https://privacy.trymito.io/privacy-policy', target: '_blank', rel: "noreferrer" },
                    React.createElement("u", null, "here")),
                ".")),
        React.createElement("div", { className: 'signup-modal-buttons' },
            React.createElement("button", { className: 'signup-modal-button-back', onClick: props.back }, " Back"),
            React.createElement("button", { className: 'signup-modal-button-next', onClick: props.next, autoFocus: true }, " Accept"))));
};
/* Step three asks the user want they want to use Mito for */
const StepThree = (props) => {
    const MainQuestion = 'Why are you using Mito?';
    const [response, setResponse] = useState('');
    const [highlightEmptyError, setHighlightEmptyError] = useState(false);
    // We store an input ref so that we can focus on the input box
    // if the user tries to submit without adding any text, just to
    // make their life easier
    let textAreaRef;
    const onSubmit = async () => {
        // Don't let the user submit if they didn't input anything
        if (response.length === 0) {
            setHighlightEmptyError(true);
            // Focus back on the input, for ease of the user
            textAreaRef === null || textAreaRef === void 0 ? void 0 : textAreaRef.focus();
            // Then, we log they tried to submit without filling it out
            // to see who really has some reason
            void props.mitoAPI.sendLogMessage('clicked_submit_empty_feedback');
            return;
        }
        // Set the feedback on what the user intends to do
        await props.mitoAPI.sendFeedback({ [MainQuestion]: response });
        // Advance to the next step
        props.next();
    };
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("div", null,
            React.createElement("h1", { className: 'mt-0' }, MainQuestion),
            React.createElement("textarea", { ref: (input) => { textAreaRef = input; }, autoFocus: true, style: {
                    border: !highlightEmptyError ? '1px solid black' : '2px solid red'
                }, className: 'feedback-taskpane-textarea', placeholder: 'I\'m an analyst at a clothing company, and I want to visualize the distribution of our customers and purchases. I\'m planning to explore my data, before presenting graphs to my manager.', value: response, onChange: (event) => { setResponse(event.target.value); } })),
        React.createElement("div", { className: 'signup-modal-buttons' },
            React.createElement("button", { className: 'signup-modal-button-back', onClick: props.back }, " Back"),
            React.createElement("button", { className: 'signup-modal-button-next', onClick: onSubmit }, " Next"))));
};
/*
    Main signup modal, which collects the users email, shows them the privacy policy,
    and then asks them what they want to do with the tool.
*/
const SignupModal = (props) => {
    const [step, setStep] = useState(1);
    const [email, setEmail] = useState('');
    const next = () => {
        if (step + 1 > 3) {
            props.setModal({ type: ModalEnum.None });
            void props.mitoAPI.sendLogMessage('finished_signup');
        }
        else {
            const newStep = Math.min(step + 1, 3);
            setStep(newStep);
            void props.mitoAPI.sendLogMessage('switched_signup_step', {
                'old_signup_step': step,
                'new_signup_step': newStep
            });
        }
    };
    const back = () => {
        const newStep = Math.max(step - 1, 0);
        setStep(newStep);
        void props.mitoAPI.sendLogMessage('switched_signup_step', {
            'old_signup_step': step,
            'new_signup_step': newStep
        });
    };
    // Background colors of the different steps right column
    const backgroundColors = {
        1: '#FFEBEB',
        2: '#FFDAAE',
        3: '#F0C5BB',
    };
    return (React.createElement("div", { className: 'overlay' },
        React.createElement("div", { className: 'signup-modal-container' },
            React.createElement("div", { className: 'signup-modal-left-column-container' },
                step === 1 &&
                    React.createElement(StepOne, { next: next, email: email, setEmail: setEmail, mitoAPI: props.mitoAPI }),
                step === 2 &&
                    React.createElement(StepTwo, { next: next, back: back }),
                step === 3 &&
                    React.createElement(StepThree, { next: next, back: back, mitoAPI: props.mitoAPI })),
            React.createElement("div", { className: 'signup-modal-right-column-container', style: { backgroundColor: backgroundColors[step] } },
                step === 1 &&
                    React.createElement(BlueMitoFolk, null),
                step === 2 &&
                    React.createElement(YellowMitoFolk, null),
                step === 3 &&
                    React.createElement(PinkMitoFolk, null)))));
};
export default SignupModal;
//# sourceMappingURL=SignupModal.js.map