// Copyright (c) Mito
import React, { useState, useEffect } from 'react';
import usePlotly from '../../../hooks/usePlotly';
/*
    Displays the column summary graph in the column control panel
*/
function ColumnSummaryGraph(props) {
    const [graphHTMLAndScript, setGraphHTMLAndScript] = useState(undefined);
    // Make sure to load plotly
    usePlotly();
    async function loadBase64PNGImage() {
        const _graphHTMLAndScript = await props.mitoAPI.getGraph(props.columnHeader, props.selectedSheetIndex, undefined, undefined, 
        // We take up half the height of the container, which scales well
        // with full screen mode
        '50%');
        setGraphHTMLAndScript(_graphHTMLAndScript);
    }
    useEffect(() => {
        void loadBase64PNGImage();
    }, []);
    // When we get a new graph script, we execute it here. This is a workaround
    // that is required because we need to make sure this code runs, which it does
    // not when it is a script tag inside innerHtml (which react does not execute
    // for safety reasons).
    useEffect(() => {
        if (graphHTMLAndScript === undefined) {
            return;
        }
        try {
            const executeScript = new Function(graphHTMLAndScript.script);
            executeScript();
        }
        catch (e) {
            console.error("Failed to execute graph function", e);
        }
    }, [graphHTMLAndScript]);
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: 'filter-modal-section-title' },
            React.createElement("p", null, " Column Summary Graph ")),
        graphHTMLAndScript !== undefined &&
            React.createElement("div", { dangerouslySetInnerHTML: { __html: graphHTMLAndScript.html } }),
        graphHTMLAndScript === undefined &&
            React.createElement("div", null, "Loading the summary graph...")));
}
export default ColumnSummaryGraph;
//# sourceMappingURL=ColumnSummaryGraph.js.map