// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
import React, { Fragment, useEffect, useState } from 'react';
import DefaultTaskpane from '../DefaultTaskpane';
import '../../../../css/feedback-taskpane.css';
// Import 
import { TaskpaneType } from '../taskpanes';
import NPS from './NPS';
// Keeps track of where you access feedback from
// so we know what is effective for getting feedback
// from users
export var FeedbackOpenLocation;
(function (FeedbackOpenLocation) {
    FeedbackOpenLocation["AUTO_POPUP"] = "Automatically Popped Up";
    FeedbackOpenLocation["FROM_DOCUMENTATION"] = "From Documentation";
})(FeedbackOpenLocation || (FeedbackOpenLocation = {}));
/*
    Taskpane that allows a user to submit feedback on their
    usage of Mito so far
*/
function FeedbackTaskpane(props) {
    const NPSQuestion = 'How likely are you to reccomend Mito to a colleague or friend?';
    const [selectedNPS, setSelectedNPS] = useState(undefined);
    const ImprovementsQuestion = 'What can we add or change to improve your experience with Mito?';
    const [improvementText, setImprovementText] = useState('');
    // Variables that we use to highlight if the user has not filled out
    // a field and they need to do so before they submit
    const [highlightEmptyNPSError, setHighlightEmptyNPSError] = useState(false);
    const [highlightEmptyImprovementError, setHighlightEmptyImprovementError] = useState(false);
    // Wrap the setter for selectedNPS so that we can log changes easily
    const changeSelectedNPS = (newSelectedNPS) => {
        // We log that the user switched
        void props.mitoAPI.sendLogMessage('changed_nps_score', {
            'old_selected_nps': selectedNPS,
            'new_selected_nps': newSelectedNPS,
        });
        // Then we actually set the value
        setSelectedNPS(newSelectedNPS);
    };
    const submitFeedback = () => {
        // Set the highlight variables correctly
        setHighlightEmptyNPSError(selectedNPS === undefined);
        setHighlightEmptyImprovementError(improvementText.length === 0);
        // Then, log that the user tried to submit with empty text, and 
        // return early
        if (selectedNPS === undefined || improvementText.length === 0) {
            void props.mitoAPI.sendLogMessage('clicked_submit_empty_feedback');
            return;
        }
        // Send a message to the backend with this feedback
        void props.mitoAPI.sendFeedback({
            'opened_location': props.openLocation,
            [NPSQuestion]: selectedNPS,
            [ImprovementsQuestion]: improvementText,
        });
        // Then, advance to the feedback thanks taskpane, to thank them
        // because we really seriously do appreciate the feedback!
        props.setCurrOpenTaskpane({ type: TaskpaneType.FEEDBACK_THANKS });
    };
    useEffect(() => {
        // We log where we opened it from, making sure to only run this once
        void props.mitoAPI.sendLogMessage('opened_feedback', { 'open_location': props.openLocation });
    }, []);
    return (React.createElement(DefaultTaskpane, { header: 'How is Mito so far?', setCurrOpenTaskpane: props.setCurrOpenTaskpane, 
        // If the feedback automatically pops up, then we don't let the user close it 
        notCloseable: props.openLocation === FeedbackOpenLocation.AUTO_POPUP, taskpaneBody: React.createElement(Fragment, null,
            React.createElement("p", { className: 'mb-10px txt-15' }, NPSQuestion),
            React.createElement(NPS, { selectedNPS: selectedNPS, setSelectedNPS: changeSelectedNPS, border: highlightEmptyNPSError ? '1px solid red' : undefined }),
            React.createElement("p", { className: 'mb-5px mt-25px txt-15' }, ImprovementsQuestion),
            React.createElement("textarea", { className: 'feedback-taskpane-textarea', style: {
                    border: !highlightEmptyImprovementError ? '1px solid black' : '2px solid red'
                }, placeholder: 'I found merge column selection confusing. Also, Excel-style formatting in the sheet would be very helpful to present data to my coworkers.', value: improvementText, onChange: (event) => { setImprovementText(event.target.value); } }),
            React.createElement("button", { className: 'blue-button txt-16 mt-20px', onClick: submitFeedback }, "Send Feedback")) }));
}
export default FeedbackTaskpane;
//# sourceMappingURL=FeedbackTaskpane.js.map